@@ -3,5 +3,7 @@
 # SPDX-FileCopyrightText: 2025 Azhar Momin <azhar.momin@kdemail.net>
 # SPDX-License-Identifier: LGPL-2.0-or-later
 
+pip3 install requests
+
 # For PoCreator
-wget https://ftp.gnu.org/gnu/gettext/gettext-0.26.tar.xz
+git clone --depth 1 git://git.savannah.gnu.org/gettext.git
